package com.oracle.howto.activemq;

import javax.jms.Connection;
import javax.jms.DeliveryMode;
import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.MessageProducer;
import javax.jms.Session;
import javax.jms.TextMessage;

import org.apache.activemq.ActiveMQConnectionFactory;

/**
 * This is a simple JMS Client which posts a message to
 * ActiveMQ queue "queue.inbound" on which the MDB listens on
 * @author sbangera
 */
public class ActiveMQApp {
    /**
     * Default constructor
     */
    public ActiveMQApp() {
    }
    
   public static void main(String args[]) throws JMSException {
    createQueue("queue.inbound");
   }
   
   /**
     * This will create a queue by the name queueName and post a TextMessage to
     * the same queue on ActiveMQ
     * @param queueName
     * @throws JMSException
     */
   public static void createQueue(String queueName) throws JMSException {
       ActiveMQConnectionFactory connectionFactory = new ActiveMQConnectionFactory("tcp://localhost:61616");

       // Create a Connection
       Connection connection = connectionFactory.createConnection();
       connection.start();

       // Create a Session
       Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);

       // Create the destination (Topic or Queue)
       Destination destination = session.createQueue(queueName);

       // Create a MessageProducer from the Session to the Topic or Queue
       MessageProducer producer = session.createProducer(destination);
       producer.setDeliveryMode(DeliveryMode.PERSISTENT);

       // Create a messages
       String text = "Hello world to ActiveMQ inbound queue!";
       TextMessage message = session.createTextMessage(text);

       // Tell the producer to send the message
       System.out.println("Sent message: "+ text);
       producer.send(message);

       // Clean up
       session.close();
       connection.close();
       
   }
   
}
