package com.oracle.howto.activemq;

import javax.ejb.EJBException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;

import javax.jms.DeliveryMode;
import javax.jms.JMSException;
import javax.jms.Queue;
import javax.jms.QueueConnection;
import javax.jms.QueueConnectionFactory;
import javax.jms.QueueSender;
import javax.jms.QueueSession;
import javax.jms.Session;
import javax.jms.TextMessage;

import javax.naming.InitialContext;
import javax.naming.NamingException;


/**
 * This is a Stateless Session Bean which is an example of
 * Outbound Communication using ActiveMQ JCA Resource Adapter
 * The Stateless Session Bean posts a message to ActiveMQ queue "queue.outbound"
 * @author sbangera
 */
public class ActiveMQEJBBean implements SessionBean {
    private SessionContext _context;
    
    /**
     * Implements the standard api.
     */
    public void ejbCreate() {
    }

    /**
     * Implements the standard api.
     * @param context
     * @throws EJBException
     */
    public void setSessionContext(SessionContext context) throws EJBException {
        _context = context;
    }

    /**
     * Implements the standard api.
     * @throws EJBException
     */
    public void ejbRemove() throws EJBException {
    }

    /**
     * Implements the standard api.
     * @throws EJBException
     */
    public void ejbActivate() throws EJBException {
    }

    /**
     * Implements the standard api.
     * @throws EJBException
     */
    public void ejbPassivate() throws EJBException {
    }

    /**
     * Posts a message to ActiveMQ queue "queue.outbound" using recvdMessage
     * @param recvdmessage
     * @throws NamingException
     * @throws JMSException
     */
    public void sendMessage(String recvdmessage) throws NamingException, 
                                                   JMSException {

        System.out.println("Message Received from MDB inside Session Bean: " + recvdmessage);                
        System.out.println("Sending Message from Stateless EJB to ActiveMQ outbound queue: " + recvdmessage);                

        InitialContext initCtx = new InitialContext();
        QueueConnectionFactory qcf = (QueueConnectionFactory) initCtx.lookup("java:comp/env/jms/QCF");
        
        QueueConnection qcon = qcf.createQueueConnection();
        QueueSession qsession = qcon.createQueueSession(true, Session.AUTO_ACKNOWLEDGE);
        Queue q = (Queue) initCtx.lookup("java:comp/env/jms/QUEUE");
        
        QueueSender qsender = qsession.createSender(q);
        

        TextMessage message = qsession.createTextMessage();
        message.setText("Message Received from MDB in Statless EJB: " + recvdmessage);
        qsender.setDeliveryMode(DeliveryMode.PERSISTENT);
        qsender.send(message);
        qsender.close();
        qsession.close();
        qcon.close();
    }
}
