package com.oracle.howto.activemq;

import javax.ejb.EJBException;
import javax.ejb.MessageDrivenBean;
import javax.ejb.MessageDrivenContext;

import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.TextMessage;

import javax.naming.Context;
import javax.naming.InitialContext;

/**
 * This is a MessageDrivenBean which consumes inbound messages posted on
 * "queue.inbound" on ActiveMQ provider.
 * @author sbangera
 */
public class ActiveMQMessageDrivenEJBBean implements MessageDrivenBean, 
                                                     MessageListener {
    private MessageDrivenContext _context;

    /**
     * Implements the standard api.
     */
    public void ejbCreate() {
    }

    /**
     * Implements the standard api.
     * @param context
     * @throws EJBException
     */
    public void setMessageDrivenContext(MessageDrivenContext context) throws EJBException {
        _context = context;
    }

    /**
     * Implements the standard api.
     * @throws EJBException
     */
    public void ejbRemove() throws EJBException {
    }
    
    /**
     * Implements the javax.jms.MessageListener.  This method will be invoked when
     * a message is delivered to the "queue.inbound" on ActiveMQ.
     * The MessageDrivenBean will post this message to a Statless Session Bean
     * @param message
     */
    public void onMessage(Message message) {
        try {
            if (message instanceof TextMessage) {
                TextMessage textMessage = (TextMessage) message;
                String messageStr = textMessage.getText();
                
                System.out.println("Inside MDB, received from inbound queue: " + messageStr);
                Context context = new InitialContext();            
                ActiveMQEJBHome activemqHome = (ActiveMQEJBHome)context.lookup("ActiveMQEJB");
                ActiveMQEJB activemqEjb = activemqHome.create();
                activemqEjb.sendMessage(messageStr);

            } else {
                  System.out.println("Unknown message type: " + message.toString());
            }
        }
        catch (JMSException e) {
            e.printStackTrace();
        }
        catch (Exception e) {
            e.printStackTrace();
        }
        

    }
}
